@@ -20,6 +20,8 @@
 Copyright (C) 2006 Reahl Software Services (Pty) Ltd.  All rights reserved. (www.reahl.org)
 
 """ 
+from __future__ import unicode_literals
+from __future__ import print_function
 
 __import__('pkg_resources').declare_namespace(__name__)
 
